@@ -408,7 +408,8 @@ brasero_medium_selection_set_active (BraseroMediumSelection *selector,
 			break;
 		}
 
-		g_object_unref (iter_medium);
+		if (iter_medium)
+			g_object_unref (iter_medium);
 	} while (gtk_tree_model_iter_next (model, &iter));
 
 	return result;
@@ -458,7 +459,7 @@ brasero_medium_selection_update_no_disc_entry (BraseroMediumSelection *self,
 	else {
 		icon = g_themed_icon_new_with_default_fallbacks ("drive-optical");
 		gtk_list_store_set (GTK_LIST_STORE (model), iter,
-				    NAME_COL, _("No available disc"),
+				    NAME_COL, _("No disc available"),
 				    ICON_COL, icon,
 				    VISIBLE_TEXT_COL, TRUE,
 				    VISIBLE_PROGRESS_COL, FALSE,
@@ -495,7 +496,6 @@ brasero_medium_selection_add_no_disc_entry (BraseroMediumSelection *self)
  * @type: a #BraseroMediaType
  *
  * Filters and displays media corresponding to @type.
- *
  **/
 void
 brasero_medium_selection_show_media_type (BraseroMediumSelection *selector,
@@ -562,10 +562,10 @@ brasero_medium_selection_show_media_type (BraseroMediumSelection *selector,
 
 			medium = item->data;
 
-			gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-			gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-					    MEDIUM_COL, medium,
-					    -1);
+			gtk_list_store_insert_with_values (GTK_LIST_STORE (model), &iter,
+			                                   -1,
+			                                   MEDIUM_COL, medium,
+			                                   -1);
 
 			medium_name = brasero_medium_selection_get_medium_string (selector, medium);
 			medium_icon = brasero_volume_get_icon (BRASERO_VOLUME (medium));
@@ -647,31 +647,81 @@ brasero_medium_selection_medium_added_cb (BraseroMediumMonitor *monitor,
 
 	priv = BRASERO_MEDIUM_SELECTION_PRIVATE (self);
 
+	model = gtk_combo_box_get_model (GTK_COMBO_BOX (self));
+
+	/* Make sure it's not already in our list */
+	if (gtk_tree_model_get_iter_first (model, &iter)) {
+		do {
+			BraseroMedium *tmp;
+
+			tmp = NULL;
+			gtk_tree_model_get (model, &iter,
+					    MEDIUM_COL, &tmp,
+					    -1);
+			if (tmp == medium)
+				return;
+
+		} while (gtk_tree_model_iter_next (model, &iter));
+	}
+
+	/* Make sure it does fit the types of media to display */
 	drive = brasero_medium_get_drive (medium);
-	if ((priv->type & BRASERO_MEDIA_TYPE_ANY_IN_BURNER)
-	&&  (brasero_drive_can_write (drive)))
+	if ((priv->type & BRASERO_MEDIA_TYPE_CD) == priv->type
+	&& (brasero_medium_get_status (medium) & BRASERO_MEDIUM_CD))
 		add = TRUE;
 
+	if ((priv->type & BRASERO_MEDIA_TYPE_ANY_IN_BURNER)
+	&&  (brasero_drive_can_write (drive))) {
+		if ((priv->type & BRASERO_MEDIA_TYPE_CD)) {
+			if (brasero_medium_get_status (medium) & BRASERO_MEDIUM_CD)
+				add = TRUE;
+		}
+		else
+			add = TRUE;
+	}
+
 	if ((priv->type & BRASERO_MEDIA_TYPE_AUDIO)
-	&&  (brasero_medium_get_status (medium) & BRASERO_MEDIUM_HAS_AUDIO))
-		add = TRUE;
+	&&  (brasero_medium_get_status (medium) & BRASERO_MEDIUM_HAS_AUDIO)) {
+		if ((priv->type & BRASERO_MEDIA_TYPE_CD)) {
+			if (brasero_medium_get_status (medium) & BRASERO_MEDIUM_CD)
+				add = TRUE;
+		}
+		else
+			add = TRUE;
+	}
 
 	if ((priv->type & BRASERO_MEDIA_TYPE_DATA)
-	&&  (brasero_medium_get_status (medium) & BRASERO_MEDIUM_HAS_DATA))
-		add = TRUE;
+	&&  (brasero_medium_get_status (medium) & BRASERO_MEDIUM_HAS_DATA)) {
+		if ((priv->type & BRASERO_MEDIA_TYPE_CD)) {
+			if (brasero_medium_get_status (medium) & BRASERO_MEDIUM_CD)
+				add = TRUE;
+		}
+		else
+			add = TRUE;
+	}
 
 	if (priv->type & BRASERO_MEDIA_TYPE_WRITABLE) {
-		if (brasero_medium_can_be_written (medium))
-			add = TRUE;
+		if (brasero_medium_can_be_written (medium)) {
+			if ((priv->type & BRASERO_MEDIA_TYPE_CD)) {
+				if (brasero_medium_get_status (medium) & BRASERO_MEDIUM_CD)
+					add = TRUE;
+			}
+			else
+				add = TRUE;
+		}
 	}
 
 	if (priv->type & BRASERO_MEDIA_TYPE_REWRITABLE) {
-		if (brasero_medium_can_be_rewritten (medium))
-			add = TRUE;
+		if (brasero_medium_can_be_rewritten (medium)) {
+			if ((priv->type & BRASERO_MEDIA_TYPE_CD)) {
+				if (brasero_medium_get_status (medium) & BRASERO_MEDIUM_CD)
+					add = TRUE;
+			}
+			else
+				add = TRUE;
+		}
 	}
 
-	model = gtk_combo_box_get_model (GTK_COMBO_BOX (self));
-
 	if (!add) {
 		BraseroMedium *tmp;
 
@@ -708,10 +758,10 @@ brasero_medium_selection_medium_added_cb (BraseroMediumMonitor *monitor,
 			g_object_unref (tmp);
 	}
 
-	gtk_list_store_append (GTK_LIST_STORE (model), &iter);
-	gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-			    MEDIUM_COL, medium,
-			    -1);
+	gtk_list_store_insert_with_values (GTK_LIST_STORE (model), &iter,
+	                                   -1,
+	                                   MEDIUM_COL, medium,
+	                                   -1);
 
 	medium_name = brasero_medium_selection_get_medium_string (self, medium);
 	medium_icon = brasero_volume_get_icon (BRASERO_VOLUME (medium));
@@ -791,7 +841,6 @@ brasero_medium_selection_init (BraseroMediumSelection *object)
 					      "medium-removed",
 					      G_CALLBACK (brasero_medium_selection_medium_removed_cb),
 					      object);
-
 	g_object_unref (monitor);
 
 	/* get the list and fill the model */
