@@ -111,7 +111,7 @@ launch_brasero_on_window_session (BraseroSessionCfg	*session,
 				  GtkWidget		*options,
 				  GtkWindow		*window)
 {
-	const gchar			*icon_name;
+	const gchar		*icon_name;
 	GtkWidget		*dialog;
 	GtkResponseType		 result;
 
@@ -136,7 +136,8 @@ launch_brasero_on_window_session (BraseroSessionCfg	*session,
 	result = gtk_dialog_run (GTK_DIALOG (dialog));
 	gtk_widget_destroy (dialog);
 
-	if (result != GTK_RESPONSE_OK)
+	if (result != GTK_RESPONSE_OK
+	&&  result != GTK_RESPONSE_ACCEPT)
 		return;
 
 	/* now run burn dialog */
@@ -151,8 +152,13 @@ launch_brasero_on_window_session (BraseroSessionCfg	*session,
 
 	gtk_widget_show (dialog);
 	gtk_window_present (GTK_WINDOW (dialog));
-	brasero_burn_dialog_run (BRASERO_BURN_DIALOG (dialog),
-				 BRASERO_BURN_SESSION (session));
+
+	if (result == GTK_RESPONSE_OK)
+		brasero_burn_dialog_run (BRASERO_BURN_DIALOG (dialog),
+					 BRASERO_BURN_SESSION (session));
+	else
+		brasero_burn_dialog_run_multi (BRASERO_BURN_DIALOG (dialog),
+					       BRASERO_BURN_SESSION (session));
 
 	gtk_widget_destroy (dialog);
 }
@@ -214,6 +220,16 @@ nautilus_disc_burn_is_empty (GtkWindow *toplevel)
 	return FALSE;
 }
 
+static void
+brasero_session_name_changed (BraseroProjectName *project_name,
+                              BraseroBurnSession *session)
+{
+	const gchar *label;
+
+	label = gtk_entry_get_text (GTK_ENTRY (project_name));
+	brasero_burn_session_set_label (session, label);
+}
+
 static void
 write_activate (GtkWindow *toplevel)
 {
@@ -239,6 +255,10 @@ write_activate (GtkWindow *toplevel)
 	name_options = brasero_project_name_new (NULL);
 	brasero_project_name_set_session (BRASERO_PROJECT_NAME (name_options),
 					  BRASERO_BURN_SESSION (session));
+	g_signal_connect (name_options,
+	                  "name-changed",
+	                  G_CALLBACK (brasero_session_name_changed),
+	                  session);
 
 	string = g_strdup_printf ("<b>%s</b>", _("Disc name"));
 	options = brasero_utils_pack_properties (string,
